from setuptools import setup, find_packages

setup(
    name='chanmeet',
    version='0.3.0',
    author='Chanmeet Singh Sahni',
    author_email='chanmeetsinghsahni@gmail.com',
    description='This is my first library',
    long_description='This library just prints my name',
    long_description_content_type='text/markdown',
    url='https://github.com/chanmeetsingh',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.11',
    ],
)
